@@ -6,7 +6,7 @@
  * Date        : 2009-08-03
  * Description : digiKam config header
  *
- * SPDX-FileCopyrightText: 2009-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2009-2023 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -18,9 +18,6 @@
 /* Define to 1 if you have KDEPIM shared library installed */
 /* #undef HAVE_AKONADICONTACT */
 
-/* Define to 1 if an external liblqr-1 shared library have been found */
-#define HAVE_LIBLQR_1 1
-
 /* Define to 1 if an external lensfun shared library have been found */
 #define HAVE_LENSFUN 1
 
@@ -78,9 +75,6 @@
 /* Define to 1 if Panorama tool is supported */
 #define HAVE_PANORAMA 1
 
-/* Define to 1 if VKontakte tool is supported */
-/* #undef HAVE_VKONTAKTE */
-
 /* Define to 1 if HTMLGallery tool is supported */
 #define HAVE_HTMLGALLERY 1
 
@@ -105,6 +99,9 @@
 /* Define to 1 if changing application styles is supported */
 #define HAVE_APPSTYLE_SUPPORT 1
 
+/* Define to 1 if system use QtMultimedia */
+/* #undef HAVE_QTMULTIMEDIA */
+
 /* Define to 1 if system use QtWebEngine */
 #define HAVE_QWEBENGINE 1
 
@@ -119,18 +116,4 @@
 
 #define LIBEXEC_INSTALL_DIR "/usr/lib/libexec"
 
-/*
- * Disable indeep warnings from Visual Studio C++
- */
-#if defined(_MSC_VER)
-// To disable warnings about no suitable definition provided for explicit template instantiation request.
-#pragma warning(disable : 4661)
-// To disable warnings about deprecated POSIX methods().
-#pragma warning(disable : 4996)
-// To disable warnings about qualifier applied to reference type ignored.
-#pragma warning(disable : 4181)
-// To disable warnings about 'storage-class-keyword' no longer supported as storage class.
-#pragma warning(disable : 5033)
-#endif
-
 #endif // DIGIKAM_CONFIG_H
